pub fn alloc_message(size: u32) -> Option<*mut MessageHeader>Expand description
Allocates space for a message in the current thread’s SPSC queue.
pub fn alloc_message(size: u32) -> Option<*mut MessageHeader>Allocates space for a message in the current thread’s SPSC queue.