ThreadBuffer

Struct ThreadBuffer 

#[repr(C)]
pub struct ThreadBuffer { pub queue: SpscVarQueue, pub should_deallocate: AtomicBool, pub name: [u8; 32], pub name_length: usize, }
Per-thread buffer containing an SPSC queue and thread metadata. Allocated on the heap via new_on_heap() (1MB+, too large for the stack).

Fields

queue: SpscVarQueue

The SPSC variable-length message queue.

should_deallocate: AtomicBool

Flag indicating whether this buffer should be deallocated by the background poller.

name: [u8; 32]

Thread name stored as raw UTF-8 bytes (up to 32 bytes).

name_length: usize

Number of valid bytes in name.

Implementations

Source

impl ThreadBuffer

pub fn new_on_heap() -> *mut Self

Allocates a zero-initialized ThreadBuffer on the heap.

pub unsafe fn free_on_heap(pointer: *mut Self)

Frees a heap-allocated ThreadBuffer.

Safety

pointer must have been returned by new_on_heap() and must only be freed once.

pub fn set_name(&mut self, thread_name: &str)

Sets the thread name, truncated to the buffer capacity (32 bytes).

pub fn name_bytes(&self) -> &[u8]

Returns the thread name as a byte slice.